module.exports = {
	description: 'correctly exports a default import, even in ES mode (#513)',
	options: { output: { name: 'myBundle' } }
};
